@@ -35,32 +35,6 @@
 #include "net.h"
 
 
-#ifndef HAVE_SETEUID
-/* HPUX doesn't have seteuid, but setuid works fine in that case for us */
-#define seteuid setuid
-#endif
-
-int DisplayMode;
-int display_mode;
-int Interactive = 1;
-int PrintVersion = 0;
-int PrintHelp = 0;
-int MaxPing = 10;
-int ForceMaxPing = 0;
-float WaitTime = 1.0;
-char *Hostname = NULL;
-char *InterfaceAddress = NULL;
-char LocalHostname[128];
-int dns = 1;
-int packetsize = 64;		/* default packet size */
-int bitpattern = 0;
-int tos = 0;
-/* begin ttl windows addByMin */
-int fstTTL = 1;			/* default start at first hop */
-//int maxTTL = MaxHost-1;		/* max you can go is 255 hops */
-int maxTTL = 30;		/* inline with traceroute */
-/* end ttl */
-
 #ifdef ENABLE_IPV6
 #define DEFAULT_AF AF_UNSPEC
 #else
@@ -69,35 +43,58 @@ int maxTTL = 30;		/* inline with traceroute */
 
 
 #ifdef NO_HERROR
-#define herror(str) printf(str ": error looking up \"%s\"\n", Hostname);
+#define herror(str) fprintf(stderr, str ": error looking up \"%s\"\n", Hostname);
 #endif
 
+
+int   DisplayMode;
+int   display_mode;
+int   Interactive = 1;
+int   PrintVersion = 0;
+int   PrintHelp = 0;
+int   MaxPing = 10;
+int   ForceMaxPing = 0;
+float WaitTime = 1.0;
+char *Hostname = NULL;
+char *InterfaceAddress = NULL;
+char  LocalHostname[128];
+int   dns = 1;
+int   packetsize = 64;          /* default packet size */
+int   bitpattern = 0;
+int   tos = 0;
 int af = DEFAULT_AF;
 
+                                /* begin ttl windows addByMin */
+int  fstTTL = 1;                /* default start at first hop */
+//int maxTTL = MaxHost-1;       /* max you can go is 255 hops */
+int   maxTTL = 30;              /* inline with traceroute */
+                                /* end ttl window stuff. */
+
+
 /* default display field(defined by key in net.h) and order */
 unsigned char fld_active[2*MAXFLD] = "LS NABWV";
-char fld_index[256];
-char available_options[MAXFLD];
+char          fld_index[256];
+char          available_options[MAXFLD];
 
 
 struct fields data_fields[MAXFLD] = {
   /* key, Remark, Header, Format, Width, CallBackFunc */
-  {' ', "<sp>: Space between fields", " ",  " ",        1, &net_drop  },   /* 0 */
-  {'L', "L: Loss Ratio",          "Loss%",  " %4.1f%%", 6, &net_loss  },   /* 1 */
-  {'D', "D: Dropped Packets",     "Drop",   " %4d",     5, &net_drop  },   /* 2 */
-  {'R', "R: Received Packets",    "Rcv",    " %5d",     6, &net_returned}, /* 3 */
-  {'S', "S: Sent Packets",        "Snt",    " %5d",     6, &net_xmit  },   /* 4 */
-  {'N', "N: Newest RTT(ms)",      "Last",   " %5.1f",   6, &net_last  },   /* 5 */
-  {'B', "B: Min/Best RTT(ms)",    "Best",   " %5.1f",   6, &net_best  },   /* 6 */
-  {'A', "A: Average RTT(ms)",     "Avg",    " %5.1f",   6, &net_avg   },   /* 7 */
-  {'W', "W: Max/Worst RTT(ms)",   "Wrst",   " %5.1f",   6, &net_worst },   /* 8 */
-  {'V', "V: Standard Deviation",  "StDev",  " %5.1f",   6, &net_stdev },   /* 9 */
-  {'G', "G: Geometric Mean",      "Gmean",  " %5.1f",   6, &net_gmean },   /* 10 */
-  {'J', "J: Current Jitter",      "Jttr",   " %4.1f",   5, &net_jitter},   /* 11 */
-  {'M', "M: Jitter Mean/Avg.",    "Javg",   " %4.1f",   5, &net_javg  },   /* 12 */
-  {'X', "X: Worst Jitter",        "Jmax",   " %4.1f",   5, &net_jworst},   /* 13 */
-  {'I', "I: Interarrival Jitter", "Jint",   " %4.1f",   5, &net_jinta },   /* 14 */
-  {'\0', 0, 0, 0, 0, 0 }
+  {' ', "<sp>: Space between fields", " ",  " ",        1, &net_drop  },
+  {'L', "L: Loss Ratio",          "Loss%",  " %4.1f%%", 6, &net_loss  },
+  {'D', "D: Dropped Packets",     "Drop",   " %4d",     5, &net_drop  },
+  {'R', "R: Received Packets",    "Rcv",    " %5d",     6, &net_returned},
+  {'S', "S: Sent Packets",        "Snt",    " %5d",     6, &net_xmit  },
+  {'N', "N: Newest RTT(ms)",      "Last",   " %5.1f",   6, &net_last  },
+  {'B', "B: Min/Best RTT(ms)",    "Best",   " %5.1f",   6, &net_best  },
+  {'A', "A: Average RTT(ms)",     "Avg",    " %5.1f",   6, &net_avg   },
+  {'W', "W: Max/Worst RTT(ms)",   "Wrst",   " %5.1f",   6, &net_worst },
+  {'V', "V: Standard Deviation",  "StDev",  " %5.1f",   6, &net_stdev },
+  {'G', "G: Geometric Mean",      "Gmean",  " %5.1f",   6, &net_gmean },
+  {'J', "J: Current Jitter",      "Jttr",   " %4.1f",   5, &net_jitter},
+  {'M', "M: Jitter Mean/Avg.",    "Javg",   " %4.1f",   5, &net_javg  },
+  {'X', "X: Worst Jitter",        "Jmax",   " %4.1f",   5, &net_jworst},
+  {'I', "I: Interarrival Jitter", "Jint",   " %4.1f",   5, &net_jinta },
+  {'\0', NULL, NULL, NULL, 0, NULL}
 };
 
 
@@ -116,7 +113,7 @@ void init_fld_options (void)
 }
 
 
-void parse_arg(int argc, char **argv) 
+void parse_arg (int argc, char **argv) 
 {
   int opt;
   int i;
@@ -188,9 +185,9 @@ void parse_arg(int argc, char **argv)
       break;
     case 's':
       packetsize = atoi (optarg);
-      if( packetsize >=0 ) {
-        if ( packetsize < MINPACKET ) packetsize = MINPACKET;
-        if ( packetsize > MAXPACKET ) packetsize = MAXPACKET;
+      if (packetsize >=0) {
+        if (packetsize < MINPACKET) packetsize = MINPACKET;
+        if (packetsize > MAXPACKET) packetsize = MAXPACKET;
       }
       break;
     case 'a':
@@ -210,19 +207,19 @@ void parse_arg(int argc, char **argv)
       break;
     case 'f':
       fstTTL = atoi (optarg);
-      if( fstTTL > maxTTL ) {
+      if (fstTTL > maxTTL) {
 	fstTTL = maxTTL;
       }
-      if( fstTTL < 1) {                       /* prevent 0 hop */
+      if (fstTTL < 1) {                       /* prevent 0 hop */
 	fstTTL = 1;
       }
       break;
     case 'm':
       maxTTL = atoi (optarg);
-      if( maxTTL > (MaxHost - 1) ) {
+      if (maxTTL > (MaxHost - 1)) {
 	maxTTL = MaxHost-1;
       }
-      if( maxTTL < 1) {                       /* prevent 0 hop */
+      if (maxTTL < 1) {                       /* prevent 0 hop */
 	maxTTL = 1;
       }
       if (fstTTL > maxTTL) {         /* don't know the pos of -m or -f */
@@ -236,7 +233,7 @@ void parse_arg(int argc, char **argv)
         exit (1);
       }
       for (i=0; optarg[i]; i++) {
-        if(!strchr(available_options, optarg[i])) {
+        if(!strchr (available_options, optarg[i])) {
           fprintf (stderr, "Unknown field identifier: %c\n", optarg[i]);
           exit (1);
         }
@@ -245,12 +242,12 @@ void parse_arg(int argc, char **argv)
       break;
     case 'b':
       bitpattern = atoi (optarg);
-      if( bitpattern > 255 ) 
+      if (bitpattern > 255)
 	bitpattern = -1;
       break;
     case 'Q':
       tos = atoi (optarg);
-      if( tos > 255 || tos <0 ) {
+      if (tos > 255 || tos < 0) {
 	/* error message, should do more checking for valid values,
 	 * details in rfc2474 */
 	tos = 0;
@@ -258,24 +255,24 @@ void parse_arg(int argc, char **argv)
       break;
     }
   }
-  
-  if(DisplayMode == DisplayReport ||
-     DisplayMode == DisplayTXT ||
-     DisplayMode == DisplayXML ||
-     DisplayMode == DisplayRaw ||
-     DisplayMode == DisplayCSV )
+
+  if (DisplayMode == DisplayReport ||
+      DisplayMode == DisplayTXT ||
+      DisplayMode == DisplayXML ||
+      DisplayMode == DisplayRaw ||
+      DisplayMode == DisplayCSV)
     Interactive = 0;
 
-  if(optind > argc - 1)
+  if (optind > argc - 1)
     return;
 
   Hostname = argv[optind++];
 
   if (argc > optind) {
-    packetsize = atoi(argv[optind]);
-    if( packetsize >=0 ) {
-      if ( packetsize < MINPACKET ) packetsize = MINPACKET;
-      if ( packetsize > MAXPACKET ) packetsize = MAXPACKET;
+    packetsize = atoi (argv[optind]);
+    if (packetsize >=0 ) {
+      if (packetsize < MINPACKET) packetsize = MINPACKET;
+      if (packetsize > MAXPACKET) packetsize = MAXPACKET;
     }
   }
 }
@@ -304,7 +301,8 @@ void parse_mtr_options (char *string)
 }
 
 
-int main(int argc, char **argv) {
+int main(int argc, char **argv) 
+{
   int               traddr;
   struct hostent *  host                = NULL;
   int               net_preopen_result;
@@ -314,19 +312,19 @@ int main(int argc, char **argv) {
   net_preopen_result = net_preopen ();
 
   /*  Now drop to user permissions  */
-  if(setuid(getuid())) {
-    printf("mtr: Unable to drop permissions.\n");
+  if (setuid(getuid())) {
+    fprintf (stderr, "mtr: Unable to drop permissions.\n");
     exit(1);
   }
 
   /*  Double check, just in case  */
-  if(geteuid() != getuid()) {
-    printf("mtr: Unable to drop permissions.\n");
+  if (geteuid() != getuid()) {
+    fprintf (stderr, "mtr: Unable to drop permissions.\n");
     exit(1);
   }
 
   /* reset the random seed */
-  srand(getpid());
+  srand (getpid());
   
   display_detect(&argc, &argv);
 
@@ -336,14 +334,14 @@ int main(int argc, char **argv) {
 
   parse_mtr_options (getenv ("MTR_OPTIONS"));
 
-  parse_arg(argc, argv);
+  parse_arg (argc, argv);
 
-  if(PrintVersion) {
-    printf("mtr " VERSION "\n");
+  if (PrintVersion) {
+    printf ("mtr " VERSION "\n");
     exit(0);
   }
 
-  if(PrintHelp) {
+  if (PrintHelp) {
     printf("usage: %s [-hvrctglsni] [--help] [--version] [--report]\n"
 	   "\t\t[--report-cycles=COUNT] [--curses] [--gtk]\n"
            "\t\t[--raw] [--split] [--no-dns] [--address interface]\n" /* BL */
@@ -351,44 +349,22 @@ int main(int argc, char **argv) {
 	   "\t\t[--interval=SECONDS] HOSTNAME [PACKETSIZE]\n", argv[0]);
     exit(0);
   }
+
   if (Hostname == NULL) Hostname = "localhost";
 
-  if(gethostname(LocalHostname, sizeof(LocalHostname))) {
+  if (gethostname(LocalHostname, sizeof(LocalHostname))) {
 	strcpy(LocalHostname, "UNKNOWNHOST");
   }
 
-  if(net_preopen_result != 0) {
-    printf("mtr: Unable to get raw socket.  (Executable not suid?)\n");
+  if (net_preopen_result != 0) {
+    fprintf(stderr, "mtr: Unable to get raw socket.  (Executable not suid?)\n");
     exit(1);
   }
 
-
-  if (InterfaceAddress) { /* Mostly borrowed from ping(1) code */
-    int i1, i2, i3, i4;
-    char dummy;
-    extern int sendsock; /* from net.c:118 */
-    extern struct sockaddr_in sourceaddress; /* from net.c:120 */
-
-    sourceaddress.sin_family = AF_INET;
-    sourceaddress.sin_port = 0;
-    sourceaddress.sin_addr.s_addr = 0;
-
-    if(sscanf(InterfaceAddress, "%u.%u.%u.%u%c", &i1, &i2, &i3, &i4, &dummy) != 4) {
-      printf("mtr: bad interface address: %s\n", InterfaceAddress);
-      exit(1);
-    } else {
-      unsigned char *ptr;
-      ptr = (unsigned char*)&sourceaddress.sin_addr;
-      ptr[0] = i1;
-      ptr[1] = i2;
-      ptr[2] = i3;
-      ptr[3] = i4;
-    }
-
-    if(bind(sendsock, (struct sockaddr*)&sourceaddress, sizeof(sourceaddress)) == -1) {
-      perror("mtr: failed to bind to interface");
-      exit(1);
-    }
+  
+  if (net_set_interfaceaddress (InterfaceAddress) != 0) {
+    fprintf (stderr, "mtr: Couldn't set interface addres.\n"); 
+    exit (1); 
   }
 
 #ifdef ENABLE_IPV6
@@ -403,24 +379,17 @@ int main(int argc, char **argv) {
     host = gethostbyname2(Hostname, af);
   }
   
-  if(host == NULL) {
+  if (host == NULL) {
     herror("mtr");
     exit(1);
   }
 
-  traddr = *(int *)host->h_addr;
-
-  if(net_open(traddr) != 0) {
-    printf("mtr: Unable to get raw socket.  (Executable not suid?)\n");
-    exit(1);
-  }
-
   switch (af) {
     case AF_INET:
       traddr = *(int *)host->h_addr;
   
-      if(net_open(traddr) != 0) {
-        printf("mtr: Unable to get raw socket.  (Executable not suid?)\n");
+      if (net_open(traddr) != 0) {
+	fprintf(stderr, "mtr: Unable to start net module.\n");
         exit(1);
       }
       break;
